==> lxqt-powermanagement_1.4.0.orig.tar.xz: lxqt-powermanagement-1.4.0/config/translations/lxqt-config-powermanagement_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>הגדרות עוקב סוללה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ה&amp;פעלת עוקב סוללה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>אזהרה:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> שניות</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>העצמה נמוכה בערך:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>סמל:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>תצוגה מקדימה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>בטעינה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>בפריקה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>כאשר עצמת המתח יורדת מתחת ל־:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>הצגת סמל:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>מערכת העיצוב</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>עיגול</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>עיגול עם אחוזים</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>סוללה עם אחוזים ורקע</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>סוללה עם אחוזים</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>מובנית</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>רמה: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>הפ&amp;עלת עוקב השהיה</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>זמן השהיה:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>הפעלת שינוי תאורה אחורית</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>כשאין פעילות עם סוללה:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>זמן חוסר פעילות על סוללה:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>תאורה אחורית (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>שניות:דקות</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>כשאין פעילות בעת חיבור לחשמל:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>זמן חוסר פעילות בעת חיבור לחשמל:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>דקות:שניות (01:30 לכל הפחות)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>בדיקת התאורה האחורית</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>כאשר בפריקת הסוללה </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>להשבית בדיקות חוסר פעילות כשבמסך מלא</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>הפעלת עוקב &amp;כיסוי</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>פעולה כשהכיסוי נסגר:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>על סוללה:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>כלום</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>תרדמת</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>כיבוי</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>עם חיבור לחשמל:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>בעת &amp;שימוש במסך חיצוני</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>הגדרות ניהול צריכת חשמל</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>סוללה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>כיסוי</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>מקשי הפעלה</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>טיפול במקשי ההפעלה</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>פעולת מקש הכיבוי:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>פעולת מקש ההשהיה:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>פעולת מקש התרדמת:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>כלום</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>לשאול</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>לנעול מסך</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>להשהות</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>תרדמת</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>לכבות</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>לכבות צגים</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_2.2.1.orig.tar.xz: lxqt-powermanagement-2.2.1/config/translations/lxqt-config-powermanagement_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>הגדרות עוקב סוללה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ה&amp;פעלת עוקב סוללה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>אזהרה:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> שניות</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>העצמה נמוכה בערך:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>סמל:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>תצוגה מקדימה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>בטעינה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>בפריקה</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>כאשר עצמת המתח יורדת מתחת ל־:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>הצגת סמל:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>מערכת העיצוב</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>עיגול</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>עיגול עם אחוזים</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>סוללה עם אחוזים ורקע</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>סוללה עם אחוזים</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>מובנית</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>רמה: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>הפ&amp;עלת עוקב השהיה</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>זמן השהיה:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>הפעלת שינוי תאורה אחורית</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>כשאין פעילות עם סוללה:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>זמן חוסר פעילות על סוללה:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>תאורה אחורית (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>שניות:דקות</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>כשאין פעילות בעת חיבור לחשמל:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>זמן חוסר פעילות בעת חיבור לחשמל:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>דקות:שניות (01:30 לכל הפחות)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>בדיקת התאורה האחורית</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>כאשר בפריקת הסוללה </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>להשבית בדיקות חוסר פעילות כשבמסך מלא</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>הפעלת עוקב &amp;כיסוי</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>פעולה כשהכיסוי נסגר:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>על סוללה:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>כלום</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>תרדמת</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>כיבוי</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>עם חיבור לחשמל:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>בעת &amp;שימוש במסך חיצוני</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>הגדרות ניהול צריכת חשמל</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>סוללה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>כיסוי</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>מקשי הפעלה</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>טיפול במקשי ההפעלה</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>פעולת מקש הכיבוי:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>פעולת מקש ההשהיה:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>פעולת מקש התרדמת:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.cpp" line="48"/>
        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
        <translation>לתשומת ליבך: תחת Wayland, כפתורי השליטה בכיבוי/הדלקה/שינה מנוהלים על ידי המנהל החלונאי במקום.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>כלום</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>לשאול</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>לנעול מסך</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>להשהות</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>תרדמת</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>לכבות</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>לכבות צגים</translation>
    </message>
</context>
</TS>
